@@ -11,10 +11,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -151,8 +151,12 @@ exo_die_command_model_init (ExoDieCommandModel *command_model)
   command_model->stamp = g_random_int ();
 
   /* spawn the collector thread */
+#if GLIB_CHECK_VERSION (2, 32, 0)
+  command_model->collect_thread = g_thread_new ("ExoCommandCollect", exo_die_command_model_collect_thread, command_model);
+#else
   command_model->collect_thread = g_thread_create_full (exo_die_command_model_collect_thread, command_model,
                                                         0, TRUE, FALSE, G_THREAD_PRIORITY_LOW, NULL);
+#endif
 }
 
 
