@@ -11,10 +11,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -150,8 +150,12 @@ exo_die_desktop_model_init (ExoDieDesktopModel *desktop_model)
   desktop_model->stamp = g_random_int ();
 
   /* spawn the collector thread */
+#if GLIB_CHECK_VERSION (2, 32, 0)
+  desktop_model->collect_thread = g_thread_new ("ExoDesktopCollect", exo_die_desktop_model_collect_thread, desktop_model);
+#else
   desktop_model->collect_thread = g_thread_create_full (exo_die_desktop_model_collect_thread, desktop_model,
                                                         0, TRUE, FALSE, G_THREAD_PRIORITY_LOW, NULL);
+#endif
 }
 
 
