@@ -13,10 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -419,6 +419,9 @@ exo_str_looks_like_an_uri (const gchar *str)
 {
   const gchar *s = str;
 
+  if (G_UNLIKELY (str == NULL))
+    return FALSE;
+
   /* <scheme> starts with an alpha character */
   if (g_ascii_isalpha (*s))
     {
@@ -426,7 +429,7 @@ exo_str_looks_like_an_uri (const gchar *str)
       for (++s; g_ascii_isalnum (*s) || *s == '+' || *s == '-' || *s == '.'; ++s);
 
       /* <scheme> must be followed by ":" */
-      return (*s == ':');
+      return (*s == ':' && *(s+1) == '/');
     }
 
   return FALSE;
